//--------------------------------------------------------------------------------------------------------------
//  Twilio × kintone ハンズオンサンプルプログラム
//  詳細画面に呼び出し用とSMS送信用のボタンを表示する。
//  それぞれクリックすると呼び出しとSMS送信をおこなう。
//  
//  SMS送信サンプルをベースに改造
//  By okiyasu
//--------------------------------------------------------------------------------------------------------------
jQuery.noConflict();

(function($, PLUGIN_ID) {
    "use strict";

    // レコード詳細表示イベント
    kintone.events.on('app.record.detail.show', function (event) {
        // Twilio認証パラメーター（Twilioダッシュボードで確認可能）
        var config = kintone.plugin.app.getConfig('hipeoligpelcgdgcclhefpflmaghakgg');
        var ACCOUNT_SID = config['account_sid'];
        var AUTH_TOKEN = config['auth_token'];
        // 呼び出し用の発信元番号。050が使用可能
        var FROM_DIAL = config['from_dial'];
        // SMS送信用の発信元番号。050が使えないので、USの番号を使用する事
        var FROM_SMS = config['from_sms'];
        // 発信時のメッセージ
        var MESSAGE_FIELD = config['message_field'];
        // 発信先の番号
        var TEL_FIELD = config['tel_field'];
        
        // 呼び出しボタンを表示
        var DialButton = document.createElement('button');
            DialButton.id = 'dial_button';
        if (FROM_DIAL === '') {
            DialButton.innerHTML = '呼び出し不可';
        } else {
            DialButton.innerHTML = '呼び出し';
            DialButton.onclick = function () {
                dial(event);
                }
        }
        kintone.app.record.getHeaderMenuSpaceElement().appendChild(DialButton);
        // 呼び出しボタンを表示
        var SendSMSButton = document.createElement('button');
            SendSMSButton.id = 'send_sms_button';
        if (FROM_SMS === '') {
            SendSMSButton.innerHTML = 'SMS送信不可';
        } else {
            SendSMSButton.innerHTML = 'SMS送信';
            SendSMSButton.onclick = function () {
                sendSMS(event);
                }
        }
        kintone.app.record.getHeaderMenuSpaceElement().appendChild(SendSMSButton);

        // SMS送信処理
        function sendSMS(event) {
            // レコードから名前と電話番号を取得
            var rec = kintone.app.record.get();
            var to = rec.record[TEL_FIELD].value;
            var message = rec.record[MESSAGE_FIELD].value;
            if (message.replace(/ /g, "").replace(/　/g, "").length === 0 || message === null) {
                message = "メッセージはありません";
            }

            // Twilio APIのURL
            var url = "https://" + ACCOUNT_SID + ":" + AUTH_TOKEN + 
                    "@api.twilio.com/2010-04-01/Accounts/" + ACCOUNT_SID + "/Messages";

            // HTTPヘッダー
            var headers = {'Content-Type': 'application/x-www-form-urlencoded'};

            // SMS送信先の電話番号（トライアルアカウントの場合は検証済み電話番号のみ送信先可能なので注意）
            // 入力されたパターンに応じてプレフィックスをつける。
            if ((" " + to).indexOf(" 0") !== -1) {
                to = (" " + to).replace(/ 0/g, "+81");
            } else if ((" " + to).indexOf(" +") === -1){
                to = "+" + to;
            }

            // 送信データ
            var data = 'From=' + encodeURIComponent(FROM_SMS) +
                        '&To=' + encodeURIComponent(to) +
                        '&Body=' + message;

            kintone.proxy(url, 'POST', headers, data, function (body, status, headers) {
                if (status === 201) {
                    alert('SMSの送信が完了しました。');
                } else {
                    alert('SMSの送信に失敗しました。¥n' + status + '¥n' + body);
                }
            });
        }


        // 呼び出し処理
        function dial(event) {

            // レコードから名前と電話番号を取得
            var rec = kintone.app.record.get();
            var tel_to = rec.record[TEL_FIELD].value;
            var message = rec.record[MESSAGE_FIELD].value;
            if (message.replace(/ /g, "").replace(/　/g, "").length === 0 || message === null) {
                message = "メッセージはありません";
            }

            // Twilio APIのURL
            var url = "https://" + ACCOUNT_SID + ":" + AUTH_TOKEN + 
                    "@api.twilio.com/2010-04-01/Accounts/" + ACCOUNT_SID + "/Calls.json";
            // HTTPヘッダー
            var headers = {'Content-Type': 'application/x-www-form-urlencoded'};

            // 発信先の電話番号（トライアルアカウントの場合は検証済み電話番号のみ発信可能なので注意）
            // 入力されたパターンに応じてプレフィックスをつける。
            // 
            if ((" " + tel_to).indexOf(" 0") !== -1) {
                tel_to = (" " + tel_to).replace(/ 0/g, "+81");
            } else if ((" " + tel_to).indexOf(" +") === -1){
                tel_to = "+" + tel_to;
            }

            // TwiMLを生成
            var twiMl = '<Response><Say voice="woman" language="ja-jp">' + 
                    message + '</Say></Response>';
            // Twimletsを利用して、TwiMLのURLを生成
            var twiMlUrl = 'http://twimlets.com/echo?Twiml='+encodeURIComponent(twiMl);
            
            // 送信データ
            var data = 'From='+encodeURIComponent(FROM_DIAL) +
                        '&To='+encodeURIComponent(tel_to) +
                        '&Url='+encodeURIComponent(twiMlUrl);
    
            kintone.proxy(url, 'POST', headers, data, function (body, status, headers) {
                if (status === 201) {
                    alert('呼び出しが完了しました。');
                } else {
                    alert('呼び出しが失敗しました。¥n' + status + '¥n' + body);
                }
            });
        }

    });

})();
